/*
 * Project name:
     I2C_Advanced (Advanced I2C Example)
 * Copyright:
     (c) mikroElektronika, 2011.
 * Revision History:
     20110202:
       - Initial release (SZ);
 * Description:
     This example features the advanced communication with the 24C02 EEPROM chip
     by introducing its own library of functions for this task: init, single
     write, single and sequential read. It performs write of a sequence of bytes
     (characters) into the EEPROM and writes this out at the first row on Lcd.
     Then, data read from EEPROM is performed and the result is displayed at the
     second row on Lcd.
 * Test configuration:
     MCU:             PIC24FJ16KA102
                      http://ww1.microchip.com/downloads/en/DeviceDoc/PIC24F16KA102_Family_datasheet_39927b.pdf
     Dev.Board:       Easy24-33 v6
                      http://www.mikroe.com/eng/products/view/494/easy24-33-v6-development-system/
     Oscillator:      HS, 8.00000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/en/compilers/mikroc/pro/dspic/
 * NOTES:
     - Pull-up I2C communication lines (RB8 and RB9)
     - Turn ON the LCD backlight
     - Turn ON SW2.1 and SW2.3.
*/

#include "EEPROM_24C02.h"

// LCD module connections
sbit LCD_RS at LATB4_bit;
sbit LCD_EN at LATB5_bit;
sbit LCD_D4 at LATB6_bit;
sbit LCD_D5 at LATA0_bit;
sbit LCD_D6 at LATA1_bit;
sbit LCD_D7 at LATA4_bit;

sbit LCD_RS_Direction at TRISB4_bit;
sbit LCD_EN_Direction at TRISB5_bit;
sbit LCD_D4_Direction at TRISB6_bit;
sbit LCD_D5_Direction at TRISA0_bit;
sbit LCD_D6_Direction at TRISA1_bit;
sbit LCD_D7_Direction at TRISA4_bit;
// End LCD module connections


char someData[] = "I2C mikroE";
char i ,tmpdata;

//  Main
void main() {

  AD1PCFG = 0x1C3F;                         // Configure AN pins as digital I/O

  EEPROM_24C02_Init();                      // performs I2C initialization
  I2C1_Init(100000);
  Lcd_Init();                               // performs Lcd initialization
  Lcd_Cmd(_LCD_CLEAR);                      // clear Lcd
  Lcd_Cmd(_LCD_CURSOR_OFF);                 // set cursor off

  // Example for single-byte write
  i = 0;
  tmpdata = 1;
  while ((tmpdata = someData[i]) != 0) {
    i++;
    EEPROM_24C02_WrSingle(i, tmpdata);      // writes data, char by char, in the EEPROM
    Delay_ms(20);
    Lcd_Chr(1,i, tmpdata);                  // diplays data on the first row of the Lcd
  }
  EEPROM_24C02_WrSingle(i+1, 0);            // writes string termination
  Delay_ms(20);

  // Example for single-byte read
  i = 1;
  tmpdata = 1;
  while ((tmpdata = EEPROM_24C02_RdSingle(i)) != 0) {
    Lcd_Chr(2,i, tmpdata);                  // displays data from EEPROM on the second row of the Lcd
    Delay_ms(20);
    i++ ;
  }

  //  Example for sequential data read
  Delay_ms(1000);
  Lcd_Cmd(_LCD_CLEAR);
  EEPROM_24C02_RdSeq(1, someData, 13);
  Lcd_Out(2,1,someData);
}