/*
 * Project name:
     SerialRAM
 * Copyright:
     (c) mikroElektronika, 2011.
 * Revision History:
     20110202:
       - Initial release (SZ);
 * Description:
     Many embedded systems need some amount of volatile storage for temporary
     data. Serial SRAMs are popular choice for volatile storage because of their
     small footprint, low I/O pin requirement, low-power consumption and low cost.
     This example writes and reads data from 23K640 Serial RAM device in byte
     read/write operation mode using standard SPI communication. For more
     information about available operating modes consult 23K640 datasheet:
     http://ww1.microchip.com/downloads/en/DeviceDoc/22126C.pdf
 * Test configuration:
     MCU:             PIC24FJ16KA102
                      http://ww1.microchip.com/downloads/en/DeviceDoc/PIC24F16KA102_Family_datasheet_39927b.pdf
     Dev.Board:       Easy24-33 v6
                      http://www.mikroe.com/eng/products/view/494/easy24-33-v6-development-system/
     Oscillator:      HS, 8.00000 MHz
     Ext. Modules:    None.
     SW:              mikroC PRO for dsPIC30/33 and PIC24
                      http://www.mikroe.com/en/compilers/mikroc/pro/dspic/
 * NOTES:
        - Turn ON: SW3.3, SW3.5 SW3.7, SW1.2, SW1.5, SW1.7 and SW1.8.
*/


// SerialRAM connections
sbit Chip_Select at RB15_bit;
sbit HOLD at RB7_bit;
sbit Chip_Select_Direction at TRISB15_bit;
sbit HOLD_Direction at TRISB7_bit;
// End SerialRAM connections

unsigned int i;
unsigned short tmp;

// Write one byte of data to specified address
void Write_Data(unsigned int address, unsigned short dat){
  Chip_Select = 0;                       // Select SerialRAM
  SPI1_Write(2);                         // Write instruction
  SPI1_Write(address >> 8);              // Sending 16 bits address
  SPI1_Write(address);
  SPI1_Write(dat);                       // Writing one byte of data
  Chip_Select = 1;                       // Deselect SerialRAM
 }

// Read one byte of data from specified address
unsigned short Read_Data(unsigned int address){
  Chip_Select = 0;                       // Select Serial RAM
  SPI1_Write(3);                         // Read instruction
  SPI1_Write(address >> 8);              // Sending 16 bits address
  SPI1_Write(address);
  tmp = SPI1_Read(0);                    // Read one byte of data
  Chip_Select = 1;                       // Deselect SerialRAM
  return tmp;
}

void main() {

  ADPCFG = 0x1C3F;                       // Configure all pins as digital I/O
  UART1_Init(9600);
  Delay_ms(10);
  UART1_Write_Text("Start");
  UART1_Write(10);
  UART1_Write(13);


  Chip_Select_Direction = 0;             // Set CS# pin as Output
  Chip_Select = 1;                       // Deselect SerialRAM
  SPI1_Init();                           // Initialize SPI module

  HOLD_Direction = 0;                    // Set HOLD# pin as output
  HOLD = 1;                              // Hold high when this function is not used



  for (i = 0; i < 256 ; i++){            // Write 256 bytes of data starting from address 0x0A00
    Write_Data(i+0x0A00, i);             // Write data to specified address
    UART1_Write(Read_Data(i+0x0A00));    // Read data and send it via UART
    Delay_ms(100);
  }
}